"""
    Flaskr
    ~~~~~~

    A microblog example application written as Flask tutorial with
    Flask and Sqlite3.

    :copyright: (c) 2010 by Armin Ronacher.
    :license: BSD, see LICENSE for more details.

    modified by bwk 1/2/2013 for MongoDB.
    start mongodb locally first:
       mongod --config /Users/bwk/mongodb-osx-x86_64-2.2.2/bin/mongodb.config

"""

from pymongo import Connection
from flask import Flask, request, session, redirect, url_for, abort, render_template

# configuration
DATABASE = 'flaskmdb1'  # change this if things break
DEBUG = True
SECRET_KEY = 'development key'
USERNAME = 'bwk'
PASSWORD = ''

# create our little application :)
app = Flask(__name__)
app.config.from_object(__name__)

db = Connection()[DATABASE]
blog = db['blog']

@app.route('/')
def show_entries():
    entries = [dict(title=cur['title'], text=cur['text']) for cur in blog.find()]
    return render_template('show_entries.html', entries=entries)


@app.route('/add', methods=['POST'])
def add_entry():
    if not session.get('logged_in'):
        abort(401)
    blog.insert({"title": request.form['title'], "text": request.form['text']}) # BUG: injection
    return redirect(url_for('show_entries'))


@app.route('/login', methods=['GET', 'POST'])
def login():
    error = None
    if request.method == 'POST':
        if request.form['username'] != app.config['USERNAME']:
            error = 'Invalid username'
        elif request.form['password'] != app.config['PASSWORD']:
            error = 'Invalid password'
        else:
            session['logged_in'] = True
            return redirect(url_for('show_entries'))
    return render_template('login.html', error=error)


@app.route('/clear', methods=['GET', 'POST'])
def clear():
    blog.remove()
    return redirect(url_for('show_entries'))


@app.route('/logout')
def logout():
    session.pop('logged_in', None)
    return redirect(url_for('show_entries'))


if __name__ == '__main__':
    app.run()

